#' hoardr
#'
#' Manage Cached Files
#'
#' @details `hoardr` is a tiny package with just a single export [hoard()].
#' The package goal is to make it easy to setup, use, and manage cached
#' files for another R package. In addition, you can export functions in
#' your own package using `hoardr` for users to manage their cached
#' files.
#'
#' @import rappdirs
#' @importFrom R6 R6Class
#' @importFrom digest digest
#' @name hoardr-package
#' @aliases hoardr
#' @docType package
#' @author Scott Chamberlain \email{myrmecocystus@@gmail.com}
#' @keywords package
"_PACKAGE"
